==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/NSLayoutAnchor.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSLayoutAnchor/*</name>*/ <T extends NSLayoutAnchor<?>>
    extends /*<extends>*/NSObject/*</extends>*/
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSLayoutAnchorPtr extends Ptr<NSLayoutAnchor, NSLayoutAnchorPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSLayoutAnchor.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSLayoutAnchor() {}
    protected NSLayoutAnchor(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "constraintEqualToAnchor:")
    public native NSLayoutConstraint equalTo(NSLayoutAnchor<T> anchor);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:")
    public native NSLayoutConstraint greaterThanOrEqual(NSLayoutAnchor<T> anchor);
    @Method(selector = "constraintLessThanOrEqualToAnchor:")
    public native NSLayoutConstraint lessThanOrEqual(NSLayoutAnchor<T> anchor);
    @Method(selector = "constraintEqualToAnchor:constant:")
    public native NSLayoutConstraint equalTo(NSLayoutAnchor<T> anchor, @MachineSizedFloat double c);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:constant:")
    public native NSLayoutConstraint greaterThanOrEqualTo(NSLayoutAnchor<T> anchor, @MachineSizedFloat double c);
    @Method(selector = "constraintLessThanOrEqualToAnchor:constant:")
    public native NSLayoutConstraint lessThanOrEqualTo(NSLayoutAnchor<T> anchor, @MachineSizedFloat double c);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/NSLayoutAnchor.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSLayoutAnchor<T extends NSObject>/*</name>*/
    extends /*<extends>*/NSObject/*</extends>*/
    /*<implements>*/implements NSCoding/*</implements>*/ {

    /*<ptr>*/public static class NSLayoutAnchorPtr<T extends NSObject> extends Ptr<NSLayoutAnchor<T>, NSLayoutAnchorPtr<T>> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSLayoutAnchor.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSLayoutAnchor() {}
    protected NSLayoutAnchor(Handle h, long handle) { super(h, handle); }
    protected NSLayoutAnchor(SkipInit skipInit) { super(skipInit); }
    @Method(selector = "initWithCoder:")
    public NSLayoutAnchor(NSCoder coder) { super((SkipInit) null); initObject(init(coder)); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "constraintEqualToAnchor:")
    public native NSLayoutConstraint equalTo(NSLayoutAnchor<T> anchor);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:")
    public native NSLayoutConstraint greaterThanOrEqual(NSLayoutAnchor<T> anchor);
    @Method(selector = "constraintLessThanOrEqualToAnchor:")
    public native NSLayoutConstraint lessThanOrEqual(NSLayoutAnchor<T> anchor);
    @Method(selector = "constraintEqualToAnchor:constant:")
    public native NSLayoutConstraint equalTo(NSLayoutAnchor<T> anchor, @MachineSizedFloat double c);
    @Method(selector = "constraintGreaterThanOrEqualToAnchor:constant:")
    public native NSLayoutConstraint greaterThanOrEqualTo(NSLayoutAnchor<T> anchor, @MachineSizedFloat double c);
    @Method(selector = "constraintLessThanOrEqualToAnchor:constant:")
    public native NSLayoutConstraint lessThanOrEqualTo(NSLayoutAnchor<T> anchor, @MachineSizedFloat double c);
    @Method(selector = "encodeWithCoder:")
    public native void encode(NSCoder coder);
    @Method(selector = "initWithCoder:")
    protected native @Pointer long init(NSCoder coder);
    /*</methods>*/
}
